@@ -19,7 +19,6 @@
 
 #include <config.h>
 
-#include <libgnome/gnome-help.h>
 #include <libgnomevfs/gnome-vfs.h>
 #include <gtk/gtk.h>
 #include <glib/gi18n.h>
@@ -33,7 +32,6 @@
 #include "procdialogs.h"
 #include "memmaps.h"
 #include "openfiles.h"
-#include "favorites.h"
 #include "load-graph.h"
 #include "disks.h"
 #include "lsof.h"
@@ -128,26 +126,6 @@ cb_show_lsof(GtkAction *action, gpointer data)
 	procman_lsof(procdata);
 }
 
-void		
-cb_show_hidden_processes (GtkAction *action, gpointer data)
-{
-	ProcData * const procdata = static_cast<ProcData*>(data);
-
-	create_blacklist_dialog (procdata);
-}
-
-
-void
-cb_hide_process (GtkAction *action, gpointer data)
-{
-	ProcData * const procdata = static_cast<ProcData*>(data);
-
-	if (procdata->config.show_hide_message)
-		procdialog_create_hide_dialog (procdata);
-	else
-		add_selected_to_blacklist (procdata);
-}
-
 
 void
 cb_about (GtkAction *action, gpointer data)
@@ -157,7 +135,7 @@ cb_about (GtkAction *action, gpointer data)
 		"Erik Johnsson",
 		"Jorgen Scheibengruber",
 		"Benoît Dejean",
-		"Paollo Borelli",
+		"Paolo Borelli",
 		NULL
 	};
 
@@ -179,7 +157,7 @@ cb_about (GtkAction *action, gpointer data)
 					  "system state"),
 		"version",		VERSION,
 		"copyright",		"Copyright \xc2\xa9 2001-2004 Kevin Vandersloot\n"
-					"Copyright \xc2\xa9 2005-2006 Benoît Dejean",
+					"Copyright \xc2\xa9 2005-2007 Benoît Dejean",
 		"logo-icon-name",	"utilities-system-monitor",
 		"authors",		authors,
 		"artists",		artists,
@@ -195,15 +173,10 @@ cb_about (GtkAction *action, gpointer data)
 void
 cb_help_contents (GtkAction *action, gpointer data)
 {
-	GError *error = NULL;
+  GnomeVFSResult res;
 
-	gnome_help_display ("gnome-system-monitor.xml", NULL, &error);
-
-	if (error != NULL)
-	{
-		g_warning (error->message);
-		g_error_free (error);
-	}
+  if ((res = gnome_vfs_url_show("ghelp:gnome-system-monitor")) != GNOME_VFS_OK)
+    g_warning("Could not display help : %s", gnome_vfs_result_to_string(res));
 }
 
 
